@@ -11,10 +11,9 @@ use strict;
 use warnings;
 
 package Dist::Zilla::Plugin::Prepender;
-# ABSTRACT: prepend lines at the top of your perl files
-$Dist::Zilla::Plugin::Prepender::VERSION = '2.002';
+# ABSTRACT: Prepend lines at the top of your perl files
+$Dist::Zilla::Plugin::Prepender::VERSION = '2.004';
 use Moose;
-use MooseX::Has::Sugar;
 
 with 'Dist::Zilla::Role::FileMunger';
 
@@ -24,17 +23,24 @@ with 'Dist::Zilla::Role::FileMunger';
 # accept some arguments multiple times.
 sub mvp_multivalue_args { qw{ line skip } }
 
-has copyright => ( ro, default => 1 );
+has copyright => (
+    is         => 'ro',
+    default    => 1,
+);
 has _lines => (
-    ro, lazy, auto_deref,
+    lazy       => 1,
     isa        => 'ArrayRef[Str]',
     init_arg   => 'line',
+    traits     => ['Array'],
+    handles    => { _lines => 'elements' },
     default    => sub { [] },
 );
 has _skips => (
-    ro, lazy, auto_deref,
+    lazy       => 1,
     isa        => 'ArrayRef[Str]',
     init_arg   => 'skip',
+    traits     => ['Array'],
+    handles    => { _skips => 'elements' },
     default    => sub { [] },
 );
 
@@ -120,11 +126,11 @@ __END__
 
 =head1 NAME
 
-Dist::Zilla::Plugin::Prepender - prepend lines at the top of your perl files
+Dist::Zilla::Plugin::Prepender - Prepend lines at the top of your perl files
 
 =head1 VERSION
 
-version 2.002
+version 2.004
 
 =head1 SYNOPSIS
 
